==> savane-1.0.1.tar.gz: savane/frontend/php/project/admin/editgroupinfo.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: editgroupinfo.php,v 1.40 2004/01/31 00:56:19 yeupou Exp $
//
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../../include/pre.php";
require  ($GLOBALS['sys_urlroot'].'/include/vars.php');

session_require(array('group'=>$group_id,'admin_flags'=>'A'));

if ($update) 
{

  group_add_history ('Changed Public Info','',$group_id);

  $result=db_query('UPDATE groups SET '
		   ."group_name='".htmlentities($form_group_name)."',"
		   ."short_description='".htmlentities($form_shortdesc)."',"
		   ."long_description='".$form_longdesc."',"

		   ."devel_status='$form_devel_status' "
		   ."WHERE group_id=$group_id");

  if (!$result) 
    { fb(_("Update failed.").' '.db_error()); }
}

// update info for page
$res_grp = db_query("SELECT * FROM groups WHERE group_id=$group_id");
if (db_numrows($res_grp) < 1) 
{
  exit_no_group();
}
$row_grp = db_fetch_array($res_grp);


site_project_header(array('title'=>_("Editing Public Infos"),'group'=>$group_id,'toptab'=>'ahome'));


// ####################################### General Description

print '
<form action="'.$PHP_SELF.'" method="post">
<input type="hidden" name="group_id" value="'.$group_id.'">
</p>

<p><font class="preinput">'
._("Descriptive Group Name (no HTML):").'
</font>
<br><input type="text" size="60" maxlen="254" name="form_group_name" value="'.$row_grp['group_name'].'">
</p>

<p><font class="preinput">'
._("Short Description (255 Character Max, no HTML):").'
</font>
<br><textarea cols="70" rows="3" wrap="virtual" name="form_shortdesc">
'.$row_grp['short_description'].'</textarea></p>

<p><font class="preinput">'
._("Long Description:").'
</font>
<br><textarea cols="70" rows="10" wrap="virtual" name="form_longdesc">'.$row_grp['long_description'].'</textarea></p>';

$type_id = $row_grp['type'];
$result1 = db_query("SELECT * FROM group_type WHERE type_id='$type_id'");
$row_grp1 = db_fetch_array($result1);

if($DEVEL_STATUS1 = $row_grp1['devel_status_array']){
  $DEVEL_STATUS=preg_split("/\n/",$DEVEL_STATUS1);
}

if ($project->CanUse("devel_status")) 
{
  print '
<p><font class="preinput">'
    ._("Development Status:").'</font><br><select name="form_devel_status">';
  while (list($k,$v) = each($DEVEL_STATUS)) 
    {
      print '<option value="'.$k.'"';
      if ($k == $row_grp['devel_status']) 
	{ print ' SELECTED'; }
      print '>'.$v;
      echo '</option>';
    }
  print '</select></p>';
}

echo '
<p><input type="submit" name="update" value="'._("Update").'">
</form>
';

project_admin_footer(array());

?>

==> savane-1.0.3.tar.gz: savane/frontend/php/project/admin/editgroupinfo.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: editgroupinfo.php,v 1.41 2004/03/13 18:22:06 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#                          Mathieu Roy <yeupou--at--gnu.org>
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "../../include/pre.php";
require  ($GLOBALS['sys_urlroot'].'/include/vars.php');

session_require(array('group'=>$group_id,'admin_flags'=>'A'));

if ($update) 
{

  group_add_history ('Changed Public Info','',$group_id);

  $result=db_query('UPDATE groups SET '
		   ."group_name='".htmlentities($form_group_name)."',"
		   ."short_description='".htmlentities($form_shortdesc)."',"
		   ."long_description='".$form_longdesc."',"

		   ."devel_status='$form_devel_status' "
		   ."WHERE group_id=$group_id");

  if (!$result) 
    { fb(_("Update failed.").' '.db_error()); }
}

# update info for page
$res_grp = db_query("SELECT * FROM groups WHERE group_id=$group_id");
if (db_numrows($res_grp) < 1) 
{
  exit_no_group();
}
$row_grp = db_fetch_array($res_grp);


site_project_header(array('title'=>_("Editing Public Infos"),'group'=>$group_id,'toptab'=>'ahome'));


# ####################################### General Description

print '
<form action="'.$PHP_SELF.'" method="post">
<input type="hidden" name="group_id" value="'.$group_id.'">
</p>

<p><font class="preinput">'
._("Descriptive Group Name (no HTML):").'
</font>
<br><input type="text" size="60" maxlen="254" name="form_group_name" value="'.$row_grp['group_name'].'">
</p>

<p><font class="preinput">'
._("Short Description (255 Character Max, no HTML):").'
</font>
<br><textarea cols="70" rows="3" wrap="virtual" name="form_shortdesc">
'.$row_grp['short_description'].'</textarea></p>

<p><font class="preinput">'
._("Long Description:").'
</font>
<br><textarea cols="70" rows="10" wrap="virtual" name="form_longdesc">'.$row_grp['long_description'].'</textarea></p>';

$type_id = $row_grp['type'];
$result1 = db_query("SELECT * FROM group_type WHERE type_id='$type_id'");
$row_grp1 = db_fetch_array($result1);

if($DEVEL_STATUS1 = $row_grp1['devel_status_array']){
  $DEVEL_STATUS=preg_split("/\n/",$DEVEL_STATUS1);
}

if ($project->CanUse("devel_status")) 
{
  print '
<p><font class="preinput">'
    ._("Development Status:").'</font><br><select name="form_devel_status">';
  while (list($k,$v) = each($DEVEL_STATUS)) 
    {
      print '<option value="'.$k.'"';
      if ($k == $row_grp['devel_status']) 
	{ print ' SELECTED'; }
      print '>'.$v;
      echo '</option>';
    }
  print '</select></p>';
}

echo '
<p><input type="submit" name="update" value="'._("Update").'">
</form>
';

project_admin_footer(array());

?>
